<?php
/**
* Author:
* Daniel P. 
* http://code.google.com/p/rcmail-thunderbird-labels/
*/

$labels = array();
$labels['label'] = 'Thunderbird Cimkék';
$labels['label0'] = 'Minden cimke törlése';
$labels['label1'] = 'Fontos';
$labels['label2'] = 'Munka';
$labels['label3'] = 'Személyes';
$labels['label4'] = 'Teendők';
$labels['label5'] = 'Később';

$messages = array();

