<?php
/**
* Author:
* Miroslav Zidek
* http://code.google.com/p/rcmail-thunderbird-labels/
*/

$labels = array();
$labels['label'] = 'Štítky Thunderbirdu';
$labels['label0'] = 'Žádný štítek';
$labels['label1'] = 'Důležité';
$labels['label2'] = 'Pracovní';
$labels['label3'] = 'Osobní';
$labels['label4'] = 'Udělat';
$labels['label5'] = 'Později';

$messages = array();

