/**
* Author:
* Michael Kefeder
* http://code.google.com/p/rcmail-thunderbird-labels/
*
* CSS is Based on a patch for roundcube 0.3 I found a long time ago
*/

#tb_label_popuplink {
  background-image: url(thunderbird_32.png);
  /*background-repeat: repeat;*/
  background-position: 50% 0px;
  width: 32px;
  height: 13px;
  padding: 28px 2px 0px 2px;
  margin: 0px 5px 0px 5px;
}

#tb_label_popup
{
  width: auto;
  position: absolute;
}

#tb_label_popup a.active
{
  color: inherit; /* fix for firefox */
}

.toolbarmenu li.label0,
.toolbarmenu li.label0 a.active
{
  color: #EEE;
}
/* Colors for single/preview message window headers display */
table.label1
{
  background-color: #FCC;
}
table.label2
{
  background-color: #FC3;
}
table.label3
{
  background-color: #3C3;
}
table.label4
{
  background-color: #99F;
}
table.label5
{
  background-color: #C9C;
}

/* Support for Thunderbird label: definition of the 5 label color */
/* Unselected (unfocused) messages */
#messagelist tr.label1 td,
#messagelist tr.label1 td a,
.toolbarmenu li.label1,
.toolbarmenu li.label1 a.active,
span.label1
{
  color: #FF0000;
}

#messagelist tr.label2 td,
#messagelist tr.label2 td a,
.toolbarmenu li.label2,
.toolbarmenu li.label2 a.active,
span.label2
{
  color: #FF9900;
}


#messagelist tr.label3 td,
#messagelist tr.label3 td a,
.toolbarmenu li.label3,
.toolbarmenu li.label3 a.active,
span.label3
{
  color: #009900;
}

#messagelist tr.label4 td,
#messagelist tr.label4 td a,
span.label4
{
  color: #3333FF;
}

/* lighter blue for dark-grey popup... */
.toolbarmenu li.label4,
.toolbarmenu li.label4 a.active
{
  color: #0CF;
}

#messagelist tr.label5 td,
#messagelist tr.label5 td a,
span.label5
{
  color: #993399;
}

/* lighter purple for dark-grey popup... */
.toolbarmenu li.label5,
.toolbarmenu li.label5 a.active
{
  color: #B6F;
}

/* Selected messages */
#messagelist tr.selected.label1 td,
#messagelist tr.selected.label1 td a,
{
  color: #FFFFFF;
  background-color: #FF0000;
}

#messagelist tr.selected.label2 td,
#messagelist tr.selected.label2 td a
{
  color: #FFFFFF;
  background-color: #FF9900;
}

#messagelist tr.selected.label3 td,
#messagelist tr.selected.label3 td a,
{
  color: #FFFFFF;
  background-color: #009900;
}

#messagelist tr.selected.label4 td,
#messagelist tr.selected.label4 td a
{
  color: #FFFFFF;
  background-color: #3333FF;
}

#messagelist tr.selected.label5 td,
#messagelist tr.selected.label5 td a
{
  color: #FFFFFF;
  background-color: #993399;
}

span.tb_label_dots {
float: right;
height: 0px;
display: block;
position:relative;
}

/* hack for firefox : doesnt display the bullets at the correct height */
@-moz-document url-prefix() {
  span.tb_label_dots {
    top: -19px;
  }
}

span.tb_label_dots span {
  font-size: 32px;
  vertical-align: middle;
  line-height: 0px;
}



div#labelbox {
  white-space: nowrap;
  position: absolute;
  right: 67px;
  top: 40px;
}

div#labelbox span {
    margin: 0 3px;
    padding: 3px;
    border: 1px solid black;
    border-radius: 3px;
    color: #black;
    font-weight: bold;
}
  
div#labelbox span.tb_label_span1 {
  background-color: #FF2200;
}

div#labelbox span.tb_label_span2 {
  background-color: #FF9900;
}

div#labelbox span.tb_label_span3 {
  background-color: #00CC00;
}

div#labelbox span.tb_label_span4 {
  background-color: #0CF;
}

div#labelbox span.tb_label_span5 {
  background-color: #FF33FF;
}  

/* icon for settings-section */
#sections-table tbody #rcmrowthunderbird_labels td.section {
	background-image: url(thunderbird_24.png);
	background-position: 3px 3px;
}

/* Non-labeled selected message: changed to make it look "like" Thunderbird */
/*#messagelist tr.selected td
{
  color: #000000;
  background-color: #F0CB82;
}
*/
/* Addition for selected RCM "flagged" message */
/*#messagelist tr.selected.flagged td
{
  color: #FFFFFF;
  background-color: #CC3333;
}
*/
/* Non specific message : changed to make it look like Thunderbird */
/*#messagelist tr.selected td a
{
  color: #000000;
}
*/
/* Addition for selected RCM "flagged" message */
/*#messagelist tr.selected.flagged td a
{
  color: #FFFFFF;
}
*/
