<?php
/**
* Author:
* master771
* http://code.google.com/p/rcmail-thunderbird-labels/
*/

$labels = array();
$labels['label'] = 'Etykiety';
$labels['label0'] = 'Brak';
$labels['label1'] = 'Ważne';
$labels['label2'] = 'Praca';
$labels['label3'] = 'Osobiste';
$labels['label4'] = 'Do zrobienia';
$labels['label5'] = 'Później';

$messages = array();

