/**
* Author:
* Michael Kefeder
* http://code.google.com/p/rcmail-thunderbird-labels/
*
* CSS is Based on a patch for roundcube 0.3 I found a long time ago
*/

#tb_label_popuplink {
  background-image: url(thunderbird_32.png);
  background-repeat: no-repeat;
  width: 32px;
  height: 32px;
  padding: 0px;
  margin: 0px 5px 0px 5px;
}

#tb_label_popup
{
  width: auto;
  position: absolute;
}

#tb_label_popup a.active
{
  color: inherit; /* fix for firefox */
}

.toolbarmenu li.label0 a
{
  color: #CCC;
}
.toolbarmenu li.label0,
.toolbarmenu li.label0 a.active
{
  color: #333;
}
.toolbarmenu li.label1 a
{
  color: #FCC;
}
.toolbarmenu li.label2 a
{
  color: #FC3;
}
.toolbarmenu li.label3 a
{
  color: #3C3;
}
.toolbarmenu li.label4 a
{
  color: #99F;
}
.toolbarmenu li.label5 a
{
  color: #C9C;
}
/* Colors for single/preview message window headers display */
table.label1
{
  background-color: #FCC;
}
table.label2
{
  background-color: #FC3;
}
table.label3
{
  background-color: #3C3;
}
table.label4
{
  background-color: #99F;
}
table.label5
{
  background-color: #C9C;
}

/* Support for Thunderbird label: definition of the 5 label color */
/* Unselected (unfocused) messages */
#messagelist tr.label1 td,
#messagelist tr.label1 td a,
.toolbarmenu li.label1,
.toolbarmenu li.label1 a.active
{
  color: #FF0000;
}

#messagelist tr.label2 td,
#messagelist tr.label2 td a,
.toolbarmenu li.label2,
.toolbarmenu li.label2 a.active
{
  color: #FF9900;
}

#messagelist tr.label3 td,
#messagelist tr.label3 td a,
.toolbarmenu li.label3,
.toolbarmenu li.label3 a.active
{
  color: #009900;
}

#messagelist tr.label4 td,
#messagelist tr.label4 td a,
.toolbarmenu li.label4,
.toolbarmenu li.label4 a.active
{
  color: #3333FF;
}

#messagelist tr.label5 td,
#messagelist tr.label5 td a,
.toolbarmenu li.label5,
.toolbarmenu li.label5 a.active
{
  color: #993399;
}

/* Selected messages */
#messagelist tr.selected.label1 td,
#messagelist tr.selected.label1 td a
{
  color: #FFFFFF;
  background-color: #FF0000;
}

#messagelist tr.selected.label2 td,
#messagelist tr.selected.label2 td a
{
  color: #FFFFFF;
  background-color: #FF9900;
}

#messagelist tr.selected.label3 td,
#messagelist tr.selected.label3 td a
{
  color: #FFFFFF;
  background-color: #009900;
}

#messagelist tr.selected.label4 td,
#messagelist tr.selected.label4 td a
{
  color: #FFFFFF;
  background-color: #3333FF;
}

#messagelist tr.selected.label5 td,
#messagelist tr.selected.label5 td a
{
  color: #FFFFFF;
  background-color: #993399;
}

/* Non-labeled selected message: changed to make it look "like" Thunderbird */
/*#messagelist tr.selected td
{
  color: #000000;
  background-color: #F0CB82;
}
*/
/* Addition for selected RCM "flagged" message */
/*#messagelist tr.selected.flagged td
{
  color: #FFFFFF;
  background-color: #CC3333;
}
*/
/* Non specific message : changed to make it look like Thunderbird */
/*#messagelist tr.selected td a
{
  color: #000000;
}
*/
/* Addition for selected RCM "flagged" message */
/*#messagelist tr.selected.flagged td a
{
  color: #FFFFFF;
}
*/
